| Portability | GHC |
|---|---|
| Stability | unstable |
| Maintainer | stephen.tetley@gmail.com |
Wumpus.Tree.DrawLoc
Description
Drawing a Tree as a LocGraphic.
- runTreeLoc :: (Real u, Floating u, InterpretUnit u) => TreeProps u a -> (elt -> LocImage u a) -> Tree elt -> LocGraphic u
Documentation
runTreeLoc :: (Real u, Floating u, InterpretUnit u) => TreeProps u a -> (elt -> LocImage u a) -> Tree elt -> LocGraphic uSource
Build a LocGraphic from a Data.Tree.
Nodes support custom drawing as the value of the label at each node is interpreted (naturally, all node drawings must be of the same type).